[asterisk-scf-commits] asterisk-scf/release/sip.git branch "master" updated.

Commits to the Asterisk SCF project code repositories asterisk-scf-commits at lists.digium.com
Mon May 14 15:32:07 CDT 2012


branch "master" has been updated
       via  94b328038ff72e9230039d302be1f66b09b0345d (commit)
      from  18a36bffd8644a4b5fe7c2515c192a8123f5be0f (commit)

Summary of changes:
 config/test_sip.conf                               |   39 ++----
 config/test_sip_state_replicator.conf              |   22 ++--
 .../SIPConfigurationIf.ice                         |    4 +-
 .../SIPStateReplicationIf.ice                      |    4 +-
 .../SIPSessionCookiesIf.ice                        |    4 +-
 slice/SIPIf.ice                                    |    4 +-
 src/AuthManager.cpp                                |    2 +-
 src/AuthManager.h                                  |    4 +-
 src/CMakeLists.txt                                 |  154 ++++++++++----------
 src/Component.cpp                                  |   20 ++--
 src/ComponentStateReplicator.cpp                   |   12 +-
 src/NATOptions.h                                   |    4 +-
 src/PJSIPLoggingModule.cpp                         |    2 +-
 src/PJSIPLoggingModule.h                           |    2 +-
 src/PJSIPLoggingModuleConstruction.cpp             |    2 +-
 src/PJSIPManager.cpp                               |    6 +-
 src/PJSIPManager.h                                 |    4 +-
 src/PJSIPModule.cpp                                |    2 +-
 src/PJSIPModule.h                                  |    6 +-
 src/PJSIPRegistrarModule.cpp                       |    2 +-
 src/PJSIPRegistrarModule.h                         |    2 +-
 src/PJSIPRegistrarModuleConstruction.cpp           |    2 +-
 src/PJSIPSessionModule.cpp                         |    6 +-
 src/PJSIPSessionModule.h                           |    4 +-
 src/PJSIPSessionModuleConstruction.cpp             |   22 ++--
 src/PJUtil.h                                       |    4 +-
 src/SIPClientRegistration.cpp                      |    8 +-
 src/SIPClientRegistration.h                        |   14 +-
 src/SIPConfiguration.cpp                           |    8 +-
 src/SIPConfiguration.h                             |    4 +-
 src/SIPEndpoint.cpp                                |   18 +-
 src/SIPEndpoint.h                                  |   20 ++--
 src/SIPEndpointFactory.cpp                         |    4 +-
 src/SIPEndpointFactory.h                           |    4 +-
 src/SIPModule.h                                    |    4 +-
 src/SIPRegistrarListener.cpp                       |    4 +-
 src/SIPRegistrarListener.h                         |    4 +-
 src/SIPReplicationContext.h                        |    6 +-
 src/SIPSession.cpp                                 |   26 ++--
 src/SIPSession.h                                   |   16 +-
 ...or.cpp => SIPSessionGatewayEndpointLocator.cpp} |    8 +-
 ...ocator.h => SIPSessionGatewayEndpointLocator.h} |    8 +-
 ...her.cpp => SIPSessionGatewayEventPublisher.cpp} |   26 ++--
 ...blisher.h => SIPSessionGatewayEventPublisher.h} |   12 +-
 src/SIPStateReplicator.h                           |   16 +-
 src/SIPStateReplicatorListener.cpp                 |    4 +-
 src/SIPTelephonyEventSink.cpp                      |    2 +-
 src/SIPTelephonyEventSink.h                        |    2 +-
 src/SIPTelephonyEventSource.cpp                    |    2 +-
 src/SIPTelephonyEventSource.h                      |    2 +-
 src/SIPTransfer.cpp                                |   12 +-
 src/SIPTransfer.h                                  |   10 +-
 src/STUNModule.cpp                                 |    4 +-
 src/STUNModule.h                                   |    4 +-
 src/STUNTransport.cpp                              |    2 +-
 src/STUNTransport.h                                |    4 +-
 src/STUNTransportConfig.cpp                        |    6 +-
 src/STUNTransportConfig.h                          |    8 +-
 src/TCPTransport.cpp                               |    2 +-
 src/TCPTransport.h                                 |    4 +-
 src/TLSTransport.cpp                               |    4 +-
 src/TLSTransport.h                                 |    4 +-
 src/Transports.cpp                                 |    2 +-
 src/Transports.h                                   |    4 +-
 src/UDPTransport.cpp                               |    2 +-
 src/UDPTransport.h                                 |    4 +-
 66 files changed, 310 insertions(+), 327 deletions(-)
 rename slice/AsteriskSCF/Configuration/{SIPSessionManager => SIPSessionGateway}/SIPConfigurationIf.ice (99%)
 rename slice/AsteriskSCF/Replication/{SIPSessionManager => SIPSessionGateway}/SIPStateReplicationIf.ice (99%)
 rename slice/AsteriskSCF/SessionCookies/{SIPSessionManager => SIPSessionGateway}/SIPSessionCookiesIf.ice (95%)
 rename src/{SIPSessionManagerEndpointLocator.cpp => SIPSessionGatewayEndpointLocator.cpp} (92%)
 rename src/{SIPSessionManagerEndpointLocator.h => SIPSessionGatewayEndpointLocator.h} (89%)
 rename src/{SIPSessionManagerEventPublisher.cpp => SIPSessionGatewayEventPublisher.cpp} (80%)
 rename src/{SIPSessionManagerEventPublisher.h => SIPSessionGatewayEventPublisher.h} (81%)


- Log -----------------------------------------------------------------
commit 94b328038ff72e9230039d302be1f66b09b0345d
Author: Ken Hunt <ken.hunt at digium.com>
Date:   Mon May 14 15:31:40 2012 -0500

    Name transition from SessionManager to SessionGateway.

diff --git a/config/test_sip.conf b/config/test_sip.conf
index e94f85d..3254e57 100644
--- a/config/test_sip.conf
+++ b/config/test_sip.conf
@@ -3,52 +3,35 @@
 # Adapter parameters for this component
 # The IP address and port specified here *must* match between master and slave
 # for Ice proxies to remain valid.
-SipSessionManagerAdapter.Endpoints=tcp -h 127.0.0.1 -p 9985
-SipSessionManagerAdapter.ThreadPool.Size=4
+SIPSessionGateway.ServiceAdapter.Endpoints=tcp -h 127.0.0.1 -p 4461
+SIPSessionGateway.ServiceAdapter.ThreadPool.Size=4
 
 # Adapter parameters for the object adapter unique to this instance of the component
 # This should have a specified IP address and port so the replica control utility can find it.
-SipSessionManagerLocalAdapter.Endpoints=default -h 127.0.0.1 
-SipSessionManagerLocalAdapter.ThreadPool.Size=4
+SIPSessionGateway.BackplaneAdapter.Endpoints=default -h 127.0.0.1 -p 4462
+SIPSessionGateway.BackplaneAdapter.ThreadPool.Size=4
 
 # A proxy to the IceStorm topic manager
-TopicManager.Proxy=AsteriskSCFIceStorm/TopicManager:default  -h 127.0.0.1 -p 10000
+TopicManager.Proxy=AsteriskSCFIceStorm/TopicManager:default  -h 127.0.0.1 -p 4421
 
 # A proxy to the service locator management service
-LocatorServiceManagement.Proxy=LocatorServiceManagement:tcp  -h 127.0.0.1 -p 4422
+LocatorServiceManagement.Proxy=LocatorServiceManagement:tcp  -h 127.0.0.1 -p 4412
 
 # A proxy to the service locator service
 LocatorService.Proxy=LocatorService:tcp -h 127.0.0.1  -p 4411
 
 # ID to use when registering with the routing service
 # Useful if registering multiple active SIP session managers
-Sip.RoutingDestinationId=pjsip
+SIPSessionGateway.SIP.RoutingDestinationId=pjsip
 
 # PJSIP Modules to register
-Sip.Modules=Session
-
-# UDP Bind address.
-Sip.Transport.UdpBindAddr=0.0.0.0:5060
+SIPSessionGateway.SIP.Modules=Session
 
 # The service name of the State replicator to use
-Sip.StateReplicatorService=default
-
-# Whether we are only a listener or not
-Sip.StateReplicatorListener=no
-
-# Endpoints that we know about
-Sip.Endpoints=cisco 18005558355
-
-
-# This is Josh's phone
-Sip.Endpoint.cisco.Session.CallDirection=Both
-
-Sip.Endpoint.18005558355.Session.CallDirection=Both
-Sip.Endpoint.18005558355.Session.SourceAddress=172.16.1.13
-Sip.Endpoint.18005558355.Transport.Address=172.16.1.10
+SIPSessionGateway.SIP.StateReplicatorService=default
 
 IceBox.InheritProperties = 1
-IceBox.Service.SipSessionManager=SipSessionManager:create
+IceBox.Service.SIPSessionGateway=SIPSessionGateway:create
 
-SipSessionManager.Standalone=true
+SIPSessionGateway.Standalone=true
 
diff --git a/config/test_sip_state_replicator.conf b/config/test_sip_state_replicator.conf
index bf46ede..ef34305 100644
--- a/config/test_sip_state_replicator.conf
+++ b/config/test_sip_state_replicator.conf
@@ -1,6 +1,6 @@
 # Adapter parameters for this component
-SipStateReplicator.Endpoints=default -h 127.0.0.1
-SipStateReplicator.ThreadPool.Size=4
+SIPStateReplicator.Endpoints=default -h 127.0.0.1
+SIPStateReplicator.ThreadPool.Size=4
 
 # A proxy to the IceStorm topic manager
 TopicManager.Proxy=AsteriskSCFIceStorm/TopicManager:default  -h 127.0.0.1 -p 10000
@@ -12,15 +12,15 @@ LocatorServiceManagement.Proxy=LocatorServiceManagement:tcp  -h 127.0.0.1 -p 442
 LocatorService.Proxy=LocatorService:tcp  -h 127.0.0.1 -p 4411
 
 # The name of the state replicator
-SipStateReplicator.Name=default
+SIPStateReplicator.Name=default
 
 IceBox.InheritProperties = 1
-IceBox.Service.SipStateReplicator=SipStateReplicator:create
+IceBox.Service.SIPStateReplicator=SIPStateReplicator:create
 
-SipStateReplicatorIceStorm.InstanceName=SipStateReplicatorIceStorm
-SipStateReplicatorIceStorm.TopicManager.Endpoints=default -h 127.0.0.1  -p 10007
-SipStateReplicatorIceStorm.Publish.Endpoints=default -h 127.0.0.1  -p 10008
-SipStateReplicatorIceStorm.Trace.TopicManager=2
-SipStateReplicatorIceStorm.Transient=1
-SipStateReplicatorIceStorm.Flush.Timeout=2000
-SipStateReplicatorTopicManager.Proxy=SipStateReplicatorIceStorm/TopicManager:default  -h 127.0.0.1 -p 10007
+SIPStateReplicatorIceStorm.InstanceName=SIPStateReplicatorIceStorm
+SIPStateReplicatorIceStorm.TopicManager.Endpoints=default -h 127.0.0.1  -p 10007
+SIPStateReplicatorIceStorm.Publish.Endpoints=default -h 127.0.0.1  -p 10008
+SIPStateReplicatorIceStorm.Trace.TopicManager=2
+SIPStateReplicatorIceStorm.Transient=1
+SIPStateReplicatorIceStorm.Flush.Timeout=2000
+SIPStateReplicatorTopicManager.Proxy=SIPStateReplicatorIceStorm/TopicManager:default  -h 127.0.0.1 -p 10007
diff --git a/slice/AsteriskSCF/Configuration/SIPSessionManager/SIPConfigurationIf.ice b/slice/AsteriskSCF/Configuration/SIPSessionGateway/SIPConfigurationIf.ice
similarity index 99%
rename from slice/AsteriskSCF/Configuration/SIPSessionManager/SIPConfigurationIf.ice
rename to slice/AsteriskSCF/Configuration/SIPSessionGateway/SIPConfigurationIf.ice
index 78e0700..416b146 100644
--- a/slice/AsteriskSCF/Configuration/SIPSessionManager/SIPConfigurationIf.ice
+++ b/slice/AsteriskSCF/Configuration/SIPSessionGateway/SIPConfigurationIf.ice
@@ -27,7 +27,7 @@ module AsteriskSCF
 module Configuration
 {
 
-module SIPSessionManager
+module SIPSessionGateway
 {
 
 ["suppress"]
@@ -621,7 +621,7 @@ class SIPRegistrationGroupRef extends SIPConfigurationItem
 
 }; /* module V1 */
 
-}; /* module SIPSessionManager */
+}; /* module SIPSessionGateway */
 
 }; /* module Configuration */
 
diff --git a/slice/AsteriskSCF/Replication/SIPSessionManager/SIPStateReplicationIf.ice b/slice/AsteriskSCF/Replication/SIPSessionGateway/SIPStateReplicationIf.ice
similarity index 99%
rename from slice/AsteriskSCF/Replication/SIPSessionManager/SIPStateReplicationIf.ice
rename to slice/AsteriskSCF/Replication/SIPSessionGateway/SIPStateReplicationIf.ice
index 0bb964c..621bf8c 100644
--- a/slice/AsteriskSCF/Replication/SIPSessionManager/SIPStateReplicationIf.ice
+++ b/slice/AsteriskSCF/Replication/SIPSessionGateway/SIPStateReplicationIf.ice
@@ -32,7 +32,7 @@ module AsteriskSCF
 module Replication
 {
 
-module SIPSessionManager
+module SIPSessionGateway
 {
 
 ["suppress"]
@@ -229,7 +229,7 @@ module V1
 
 }; /* module V1 */
 
-}; /* module SIPSessionManager */
+}; /* module SIPSessionGateway */
 
 }; /* module Replication */
 
diff --git a/slice/AsteriskSCF/SessionCookies/SIPSessionManager/SIPSessionCookiesIf.ice b/slice/AsteriskSCF/SessionCookies/SIPSessionGateway/SIPSessionCookiesIf.ice
similarity index 95%
rename from slice/AsteriskSCF/SessionCookies/SIPSessionManager/SIPSessionCookiesIf.ice
rename to slice/AsteriskSCF/SessionCookies/SIPSessionGateway/SIPSessionCookiesIf.ice
index a34f8ea..373df71 100644
--- a/slice/AsteriskSCF/SessionCookies/SIPSessionManager/SIPSessionCookiesIf.ice
+++ b/slice/AsteriskSCF/SessionCookies/SIPSessionGateway/SIPSessionCookiesIf.ice
@@ -24,7 +24,7 @@ module AsteriskSCF
 module SessionCookies
 {
 
-module SIPSessionManager
+module SIPSessionGateway
 {
 
 ["suppress"]
@@ -45,6 +45,6 @@ unsliceable class ReferredByCookie extends AsteriskSCF::SessionCommunications::V
 };
 
 }; //end module V1
-}; //end module SIPSessionManager
+}; //end module SIPSessionGateway
 }; //end module SessionCookies
 }; //end module AsteriskSCF
diff --git a/slice/SIPIf.ice b/slice/SIPIf.ice
index 617f44c..0488b35 100644
--- a/slice/SIPIf.ice
+++ b/slice/SIPIf.ice
@@ -26,7 +26,7 @@ module SIP
 module V1
 {
    const string Version = "V1";
-   const string ComponentServiceDiscoveryCategory = "SIPSessionManager";
+   const string ComponentServiceDiscoveryCategory = "SIPSessionGateway";
    const string AuthExtensionPointCategory = "SIPAuthExtensionPoint";
 
    // A submodule for our event publication.
@@ -43,7 +43,7 @@ module V1
    /**
     * Interface for monitoring the SIP Session Manager events. 
     */
-   interface SIPSessionManagerEvents
+   interface SIPSessionGatewayEvents
    {
       /**
        * Notification that a lookup was attempted on our published EndpointLocator.
diff --git a/src/AuthManager.cpp b/src/AuthManager.cpp
index e36f718..b111a4e 100644
--- a/src/AuthManager.cpp
+++ b/src/AuthManager.cpp
@@ -25,7 +25,7 @@ using namespace AsteriskSCF::System::Logging;
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class AuthHookWrapper
diff --git a/src/AuthManager.h b/src/AuthManager.h
index a07272b..23d0d0e 100644
--- a/src/AuthManager.h
+++ b/src/AuthManager.h
@@ -27,7 +27,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class AuthHookWrapper;
@@ -198,5 +198,5 @@ private:
 
 typedef boost::shared_ptr<AuthManager> AuthManagerPtr;
 
-}; //end namespace SIPSessionManager
+}; //end namespace SIPSessionGateway
 }; //end namespace AsteriskSCF
diff --git a/src/CMakeLists.txt b/src/CMakeLists.txt
index aa40d6f..3e602da 100644
--- a/src/CMakeLists.txt
+++ b/src/CMakeLists.txt
@@ -15,89 +15,89 @@ if(${CMAKE_CL_64})
     add_definitions("/bigobj")
 endif()
 
-astscf_component_init(SIPSessionManager)
-astscf_component_add_files(SIPSessionManager Component.cpp)
-astscf_component_add_files(SIPSessionManager SIPReplicationContext.h)
-astscf_component_add_files(SIPSessionManager SIPSessionManagerEventPublisher.cpp)
-astscf_component_add_files(SIPSessionManager SIPSessionManagerEventPublisher.h)
-astscf_component_add_files(SIPSessionManager SIPSessionManagerEndpointLocator.cpp)
-astscf_component_add_files(SIPSessionManager SIPSessionManagerEndpointLocator.h)
-astscf_component_add_files(SIPSessionManager SIPEndpointFactory.cpp)
-astscf_component_add_files(SIPSessionManager SIPEndpointFactory.h)
-astscf_component_add_files(SIPSessionManager SIPEndpoint.cpp)
-astscf_component_add_files(SIPSessionManager SIPEndpoint.h)
-astscf_component_add_files(SIPSessionManager SIPSession.cpp)
-astscf_component_add_files(SIPSessionManager SIPSession.h)
-astscf_component_add_files(SIPSessionManager SIPTelephonyEventSource.cpp)
-astscf_component_add_files(SIPSessionManager SIPTelephonyEventSource.h)
-astscf_component_add_files(SIPSessionManager SIPTelephonyEventSink.cpp)
-astscf_component_add_files(SIPSessionManager SIPTelephonyEventSink.h)
-astscf_component_add_files(SIPSessionManager PJSIPManager.cpp)
-astscf_component_add_files(SIPSessionManager PJSIPManager.h)
-astscf_component_add_files(SIPSessionManager PJSIPModule.cpp)
-astscf_component_add_files(SIPSessionManager PJSIPModule.h)
-astscf_component_add_files(SIPSessionManager SIPTransfer.cpp)
-astscf_component_add_files(SIPSessionManager SIPTransfer.h)
-astscf_component_add_files(SIPSessionManager PJSIPSessionModule.cpp)
-astscf_component_add_files(SIPSessionManager PJSIPSessionModuleConstruction.cpp)
-astscf_component_add_files(SIPSessionManager PJSIPSessionModule.h)
-astscf_component_add_files(SIPSessionManager PJSIPLoggingModule.cpp)
-astscf_component_add_files(SIPSessionManager PJSIPLoggingModuleConstruction.cpp)
-astscf_component_add_files(SIPSessionManager PJSIPLoggingModule.h)
-astscf_component_add_files(SIPSessionManager PJSIPRegistrarModule.cpp)
-astscf_component_add_files(SIPSessionManager PJSIPRegistrarModuleConstruction.cpp)
-astscf_component_add_files(SIPSessionManager PJSIPRegistrarModule.h)
-astscf_component_add_files(SIPSessionManager SIPClientRegistration.cpp)
-astscf_component_add_files(SIPSessionManager SIPClientRegistration.h)
-astscf_component_add_files(SIPSessionManager AuthManager.cpp)
-astscf_component_add_files(SIPSessionManager AuthManager.h)
-astscf_component_add_files(SIPSessionManager SIPConfiguration.cpp)
-astscf_component_add_files(SIPSessionManager SIPConfiguration.h)
-astscf_component_add_files(SIPSessionManager SIPStateReplicatorListener.cpp)
-astscf_component_add_files(SIPSessionManager SIPStateReplicator.h)
-astscf_component_add_files(SIPSessionManager Transports.cpp)
-astscf_component_add_files(SIPSessionManager Transports.h)
-astscf_component_add_files(SIPSessionManager UDPTransport.cpp)
-astscf_component_add_files(SIPSessionManager UDPTransport.h)
-astscf_component_add_files(SIPSessionManager TCPTransport.cpp)
-astscf_component_add_files(SIPSessionManager TCPTransport.h)
-astscf_component_add_files(SIPSessionManager TLSTransport.cpp)
-astscf_component_add_files(SIPSessionManager TLSTransport.h)
-astscf_component_add_files(SIPSessionManager PJUtil.h)
-astscf_component_add_files(SIPSessionManager DebugUtil.h)
-astscf_component_add_files(SIPSessionManager SIPModule.h)
-astscf_component_add_files(SIPSessionManager STUNModule.cpp)
-astscf_component_add_files(SIPSessionManager STUNModule.h)
-astscf_component_add_files(SIPSessionManager STUNTransport.cpp)
-astscf_component_add_files(SIPSessionManager STUNTransport.h)
-astscf_component_add_files(SIPSessionManager STUNTransportConfig.cpp)
-astscf_component_add_files(SIPSessionManager STUNTransportConfig.h)
-astscf_component_add_files(SIPSessionManager NATOptions.h)
-astscf_component_add_files(SIPSessionManager SIPRegistrarListener.cpp)
-astscf_component_add_files(SIPSessionManager SIPRegistrarListener.h)
-astscf_component_add_slices(SIPSessionManager PROJECT SIPIf.ice)
-astscf_component_add_slices(SIPSessionManager PROJECT AsteriskSCF/Replication/SIPSessionManager/SIPStateReplicationIf.ice)
-astscf_component_add_slices(SIPSessionManager PROJECT AsteriskSCF/Configuration/SIPSessionManager/SIPConfigurationIf.ice)
-astscf_component_add_slices(SIPSessionManager PROJECT AsteriskSCF/SessionCookies/SIPSessionManager/SIPSessionCookiesIf.ice)
-astscf_component_add_ice_libraries(SIPSessionManager IceStorm)
-astscf_component_add_boost_libraries(SIPSessionManager core)
-astscf_component_add_slice_collection_libraries(SIPSessionManager ASTSCF)
-astscf_component_build_icebox(SIPSessionManager)
-target_link_libraries(SIPSessionManager LoggingClient ASTSCFIceUtilCpp ASTSCFIceUtilCppPJLIB ${OPENSSL_LIBRARIES})
+astscf_component_init(SIPSessionGateway)
+astscf_component_add_files(SIPSessionGateway Component.cpp)
+astscf_component_add_files(SIPSessionGateway SIPReplicationContext.h)
+astscf_component_add_files(SIPSessionGateway SIPSessionGatewayEventPublisher.cpp)
+astscf_component_add_files(SIPSessionGateway SIPSessionGatewayEventPublisher.h)
+astscf_component_add_files(SIPSessionGateway SIPSessionGatewayEndpointLocator.cpp)
+astscf_component_add_files(SIPSessionGateway SIPSessionGatewayEndpointLocator.h)
+astscf_component_add_files(SIPSessionGateway SIPEndpointFactory.cpp)
+astscf_component_add_files(SIPSessionGateway SIPEndpointFactory.h)
+astscf_component_add_files(SIPSessionGateway SIPEndpoint.cpp)
+astscf_component_add_files(SIPSessionGateway SIPEndpoint.h)
+astscf_component_add_files(SIPSessionGateway SIPSession.cpp)
+astscf_component_add_files(SIPSessionGateway SIPSession.h)
+astscf_component_add_files(SIPSessionGateway SIPTelephonyEventSource.cpp)
+astscf_component_add_files(SIPSessionGateway SIPTelephonyEventSource.h)
+astscf_component_add_files(SIPSessionGateway SIPTelephonyEventSink.cpp)
+astscf_component_add_files(SIPSessionGateway SIPTelephonyEventSink.h)
+astscf_component_add_files(SIPSessionGateway PJSIPManager.cpp)
+astscf_component_add_files(SIPSessionGateway PJSIPManager.h)
+astscf_component_add_files(SIPSessionGateway PJSIPModule.cpp)
+astscf_component_add_files(SIPSessionGateway PJSIPModule.h)
+astscf_component_add_files(SIPSessionGateway SIPTransfer.cpp)
+astscf_component_add_files(SIPSessionGateway SIPTransfer.h)
+astscf_component_add_files(SIPSessionGateway PJSIPSessionModule.cpp)
+astscf_component_add_files(SIPSessionGateway PJSIPSessionModuleConstruction.cpp)
+astscf_component_add_files(SIPSessionGateway PJSIPSessionModule.h)
+astscf_component_add_files(SIPSessionGateway PJSIPLoggingModule.cpp)
+astscf_component_add_files(SIPSessionGateway PJSIPLoggingModuleConstruction.cpp)
+astscf_component_add_files(SIPSessionGateway PJSIPLoggingModule.h)
+astscf_component_add_files(SIPSessionGateway PJSIPRegistrarModule.cpp)
+astscf_component_add_files(SIPSessionGateway PJSIPRegistrarModuleConstruction.cpp)
+astscf_component_add_files(SIPSessionGateway PJSIPRegistrarModule.h)
+astscf_component_add_files(SIPSessionGateway SIPClientRegistration.cpp)
+astscf_component_add_files(SIPSessionGateway SIPClientRegistration.h)
+astscf_component_add_files(SIPSessionGateway AuthManager.cpp)
+astscf_component_add_files(SIPSessionGateway AuthManager.h)
+astscf_component_add_files(SIPSessionGateway SIPConfiguration.cpp)
+astscf_component_add_files(SIPSessionGateway SIPConfiguration.h)
+astscf_component_add_files(SIPSessionGateway SIPStateReplicatorListener.cpp)
+astscf_component_add_files(SIPSessionGateway SIPStateReplicator.h)
+astscf_component_add_files(SIPSessionGateway Transports.cpp)
+astscf_component_add_files(SIPSessionGateway Transports.h)
+astscf_component_add_files(SIPSessionGateway UDPTransport.cpp)
+astscf_component_add_files(SIPSessionGateway UDPTransport.h)
+astscf_component_add_files(SIPSessionGateway TCPTransport.cpp)
+astscf_component_add_files(SIPSessionGateway TCPTransport.h)
+astscf_component_add_files(SIPSessionGateway TLSTransport.cpp)
+astscf_component_add_files(SIPSessionGateway TLSTransport.h)
+astscf_component_add_files(SIPSessionGateway PJUtil.h)
+astscf_component_add_files(SIPSessionGateway DebugUtil.h)
+astscf_component_add_files(SIPSessionGateway SIPModule.h)
+astscf_component_add_files(SIPSessionGateway STUNModule.cpp)
+astscf_component_add_files(SIPSessionGateway STUNModule.h)
+astscf_component_add_files(SIPSessionGateway STUNTransport.cpp)
+astscf_component_add_files(SIPSessionGateway STUNTransport.h)
+astscf_component_add_files(SIPSessionGateway STUNTransportConfig.cpp)
+astscf_component_add_files(SIPSessionGateway STUNTransportConfig.h)
+astscf_component_add_files(SIPSessionGateway NATOptions.h)
+astscf_component_add_files(SIPSessionGateway SIPRegistrarListener.cpp)
+astscf_component_add_files(SIPSessionGateway SIPRegistrarListener.h)
+astscf_component_add_slices(SIPSessionGateway PROJECT SIPIf.ice)
+astscf_component_add_slices(SIPSessionGateway PROJECT AsteriskSCF/Replication/SIPSessionGateway/SIPStateReplicationIf.ice)
+astscf_component_add_slices(SIPSessionGateway PROJECT AsteriskSCF/Configuration/SIPSessionGateway/SIPConfigurationIf.ice)
+astscf_component_add_slices(SIPSessionGateway PROJECT AsteriskSCF/SessionCookies/SIPSessionGateway/SIPSessionCookiesIf.ice)
+astscf_component_add_ice_libraries(SIPSessionGateway IceStorm)
+astscf_component_add_boost_libraries(SIPSessionGateway core)
+astscf_component_add_slice_collection_libraries(SIPSessionGateway ASTSCF)
+astscf_component_build_icebox(SIPSessionGateway)
+target_link_libraries(SIPSessionGateway LoggingClient ASTSCFIceUtilCpp ASTSCFIceUtilCppPJLIB ${OPENSSL_LIBRARIES})
 
-pjproject_link(SIPSessionManager pjsip)
-pjproject_link(SIPSessionManager pjmedia)
-pjproject_link(SIPSessionManager pjnath)
-pjproject_link(SIPSessionManager pjlib-util)
-pjproject_link(SIPSessionManager pjlib)
-astscf_component_install(SIPSessionManager)
+pjproject_link(SIPSessionGateway pjsip)
+pjproject_link(SIPSessionGateway pjmedia)
+pjproject_link(SIPSessionGateway pjnath)
+pjproject_link(SIPSessionGateway pjlib-util)
+pjproject_link(SIPSessionGateway pjlib)
+astscf_component_install(SIPSessionGateway)
 
 astscf_component_init(SIPStateReplicator)
 astscf_component_add_files(SIPStateReplicator ComponentStateReplicator.cpp)
 astscf_component_add_files(SIPStateReplicator SIPStateReplicator.h)
 astscf_component_add_slices(SIPStateReplicator PROJECT SIPIf.ice)
-astscf_component_add_slices(SIPStateReplicator PROJECT AsteriskSCF/Replication/SIPSessionManager/SIPStateReplicationIf.ice)
-astscf_component_add_slices(SIPStateReplicator PROJECT AsteriskSCF/Configuration/SIPSessionManager/SIPConfigurationIf.ice)
+astscf_component_add_slices(SIPStateReplicator PROJECT AsteriskSCF/Replication/SIPSessionGateway/SIPStateReplicationIf.ice)
+astscf_component_add_slices(SIPStateReplicator PROJECT AsteriskSCF/Configuration/SIPSessionGateway/SIPConfigurationIf.ice)
 astscf_component_add_ice_libraries(SIPStateReplicator IceStorm)
 astscf_component_add_boost_libraries(SIPStateReplicator thread date_time)
 astscf_component_add_slice_collection_libraries(SIPStateReplicator ASTSCF)
diff --git a/src/Component.cpp b/src/Component.cpp
index e353b2f..707cb76 100644
--- a/src/Component.cpp
+++ b/src/Component.cpp
@@ -36,8 +36,8 @@
 #include <AsteriskSCF/PJLIB/ThreadHook.h>
 #include <AsteriskSCF/Replication/ReplicationContext.h>
 
-#include "SIPSessionManagerEventPublisher.h"
-#include "SIPSessionManagerEndpointLocator.h"
+#include "SIPSessionGatewayEventPublisher.h"
+#include "SIPSessionGatewayEndpointLocator.h"
 #include "SIPEndpointFactory.h"
 #include "PJSIPSessionModule.h"
 #include "PJSIPManager.h"
@@ -48,8 +48,8 @@
 #include "SIPReplicationContext.h"
 
 using namespace std;
-using namespace AsteriskSCF::SIPSessionManager;
-using namespace AsteriskSCF::Configuration::SIPSessionManager::V1;
+using namespace AsteriskSCF::SIPSessionGateway;
+using namespace AsteriskSCF::Configuration::SIPSessionGateway::V1;
 using namespace AsteriskSCF::Core;
 using namespace AsteriskSCF::Core::Routing::V1;
 using namespace AsteriskSCF::Core::Discovery::V1;
@@ -72,7 +72,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class SIPAuthExtensionPoint : public AuthExtensionPoint
@@ -175,7 +175,7 @@ private:
     SIPStateReplicatorListenerPrx mReplicatorListenerProxy;
 
     // Implementation support classes
-    boost::shared_ptr<SIPSessionManagerEventPublisher> mEventPublisher;
+    boost::shared_ptr<SIPSessionGatewayEventPublisher> mEventPublisher;
     Routing::V1::EndpointLocatorPtr mEndpointLocator;
     boost::shared_ptr<SIPEndpointFactory> mEndpointFactory;
     PJSIPManagerPtr mPJSIPManager;
@@ -537,7 +537,7 @@ void Component::createPrimaryServices()
         SIPReplicationContextPtr sipReplicationContext =
             boost::static_pointer_cast<SIPReplicationContext>(getReplicationContext());
 
-        mEventPublisher.reset(new SIPSessionManagerEventPublisher(getServiceAdapter()));
+        mEventPublisher.reset(new SIPSessionGatewayEventPublisher(getServiceAdapter()));
         lg(Debug) << "Created SIP Session Manager event publisher";
 
         mEndpointFactory.reset(new SIPEndpointFactory(
@@ -555,7 +555,7 @@ void Component::createPrimaryServices()
         locateRoutingService();
 
         // Create and configure our Endpoint Locator.
-        mEndpointLocator = new SIPSessionManagerEndpointLocator(mEndpointFactory);
+        mEndpointLocator = new SIPSessionGatewayEndpointLocator(mEndpointFactory);
         getServiceAdapter()->add(mEndpointLocator, getCommunicator()->stringToIdentity(EndpointLocatorObjectId));
         lg(Debug) << "Got proxy to endpoint locator";
 
@@ -646,9 +646,9 @@ extern "C"
 {
 ASTSCF_DLL_EXPORT IceBox::Service* create(Ice::CommunicatorPtr)
 {
-    return new AsteriskSCF::SIPSessionManager::Component;
+    return new AsteriskSCF::SIPSessionGateway::Component;
 }
 }
 
-}; // end SIPSessionManager
+}; // end SIPSessionGateway
 }; // end AsteriskSCF
diff --git a/src/ComponentStateReplicator.cpp b/src/ComponentStateReplicator.cpp
index d2f6383..b8b1be9 100644
--- a/src/ComponentStateReplicator.cpp
+++ b/src/ComponentStateReplicator.cpp
@@ -27,16 +27,16 @@
 using namespace std;
 using namespace AsteriskSCF::Core;
 using namespace AsteriskSCF::Core::Discovery::V1;
-using namespace AsteriskSCF::Replication::SIPSessionManager::V1;
+using namespace AsteriskSCF::Replication::SIPSessionGateway::V1;
 using namespace AsteriskSCF::System::Component::V1;
 using namespace AsteriskSCF::System::Logging;
-using namespace AsteriskSCF::SIPSessionManager;
+using namespace AsteriskSCF::SIPSessionGateway;
 
 using namespace AsteriskSCF::Discovery;
 
 namespace
 {
-Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionManagerReplicator");
+Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGatewayReplicator");
 }
 
 class ComponentStateReplicator : public AsteriskSCF::Component::ComponentStateReplicator
@@ -44,9 +44,9 @@ class ComponentStateReplicator : public AsteriskSCF::Component::ComponentStateRe
 public:
     ComponentStateReplicator() :
       AsteriskSCF::Component::ComponentStateReplicator(lg, 
-          AsteriskSCF::Replication::SIPSessionManager::V1::StateReplicatorComponentCategory, 
+          AsteriskSCF::Replication::SIPSessionGateway::V1::StateReplicatorComponentCategory, 
           true,                               // if true, supports configuration
-          AsteriskSCF::Configuration::SIPSessionManager::V1::ConfigurationDiscoveryCategory) 
+          AsteriskSCF::Configuration::SIPSessionGateway::V1::ConfigurationDiscoveryCategory) 
     {
     }
 
@@ -78,7 +78,7 @@ void ComponentStateReplicator::preparePrimaryServicesForDiscovery()
     {
         // Wrap our authentication extensions point for the Service Locator.
         mStateReplicatorRegistration = wrapServiceForRegistration(mStateReplicatorPrx,
-                                                                  AsteriskSCF::Replication::SIPSessionManager::V1::StateReplicatorDiscoveryCategory);
+                                                                  AsteriskSCF::Replication::SIPSessionGateway::V1::StateReplicatorDiscoveryCategory);
         managePrimaryService(mStateReplicatorRegistration);
     }
     catch(const std::exception& e)
diff --git a/src/PJSIPLoggingModule.cpp b/src/PJSIPLoggingModule.cpp
index 1397204..5d11c4d 100644
--- a/src/PJSIPLoggingModule.cpp
+++ b/src/PJSIPLoggingModule.cpp
@@ -29,7 +29,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 pj_status_t PJSIPLoggingModule::load(pjsip_endpoint*)
diff --git a/src/PJSIPLoggingModule.h b/src/PJSIPLoggingModule.h
index e0d49fa..3d5efd0 100644
--- a/src/PJSIPLoggingModule.h
+++ b/src/PJSIPLoggingModule.h
@@ -21,7 +21,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class PJSIPLoggingModule : public PJSIPModule
diff --git a/src/PJSIPLoggingModuleConstruction.cpp b/src/PJSIPLoggingModuleConstruction.cpp
index f5d809a..04365da 100644
--- a/src/PJSIPLoggingModuleConstruction.cpp
+++ b/src/PJSIPLoggingModuleConstruction.cpp
@@ -19,7 +19,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 static PJSIPLoggingModule *loggingModule;
diff --git a/src/PJSIPManager.cpp b/src/PJSIPManager.cpp
index 11a917a..10fa36b 100644
--- a/src/PJSIPManager.cpp
+++ b/src/PJSIPManager.cpp
@@ -47,7 +47,7 @@ const std::string RegistrarId("SIPRegistrar");
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::SIP::Registration::V1;
@@ -99,7 +99,7 @@ static void *monitorThread(void *endpt)
     return NULL;
 }
 
-PJSIPManagerPtr AsteriskSCF::SIPSessionManager::PJSIPManager::create(const std::string& managerName,
+PJSIPManagerPtr AsteriskSCF::SIPSessionGateway::PJSIPManager::create(const std::string& managerName,
         const Ice::PropertiesPtr& properties)
 {
     PJSIPManagerPtr result(new PJSIPManager);
@@ -302,6 +302,6 @@ PJSIPManager::PJSIPManager() :
     }
 }
 
-}; //End namespace SIPSessionManager
+}; //End namespace SIPSessionGateway
 
 }; //End namespace AsteriskSCF
diff --git a/src/PJSIPManager.h b/src/PJSIPManager.h
index ca10ca6..e5eecef 100644
--- a/src/PJSIPManager.h
+++ b/src/PJSIPManager.h
@@ -39,7 +39,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class PJSIPManager;
@@ -163,6 +163,6 @@ private:
     PJSIPManager();
 };
 
-}; //End namespace SIPSessionManager
+}; //End namespace SIPSessionGateway
 
 }; //End namespace AsteriskSCF
diff --git a/src/PJSIPModule.cpp b/src/PJSIPModule.cpp
index 37ffe31..915cbf6 100644
--- a/src/PJSIPModule.cpp
+++ b/src/PJSIPModule.cpp
@@ -29,7 +29,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 //Arbitrarily chosen URI size. Used for times when I need
diff --git a/src/PJSIPModule.h b/src/PJSIPModule.h
index f655efd..aa66136 100644
--- a/src/PJSIPModule.h
+++ b/src/PJSIPModule.h
@@ -31,10 +31,10 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
-using namespace AsteriskSCF::Replication::SIPSessionManager::V1;
+using namespace AsteriskSCF::Replication::SIPSessionGateway::V1;
 
 class PJSIPModule : public IceUtil::Shared
 {
@@ -86,5 +86,5 @@ private:
     TransactionState transactionStateTranslate(pjsip_tsx_state_e state);
 };
 
-}; //end namespace SIPSessionManager
+}; //end namespace SIPSessionGateway
 }; //end namespace AsteriskSCF
diff --git a/src/PJSIPRegistrarModule.cpp b/src/PJSIPRegistrarModule.cpp
index d2df307..1821f41 100644
--- a/src/PJSIPRegistrarModule.cpp
+++ b/src/PJSIPRegistrarModule.cpp
@@ -43,7 +43,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class RegistrationExpired : public Work, public IceUtil::TimerTask
diff --git a/src/PJSIPRegistrarModule.h b/src/PJSIPRegistrarModule.h
index ea0211b..43dc6a6 100644
--- a/src/PJSIPRegistrarModule.h
+++ b/src/PJSIPRegistrarModule.h
@@ -28,7 +28,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class BindingWrapper;
diff --git a/src/PJSIPRegistrarModuleConstruction.cpp b/src/PJSIPRegistrarModuleConstruction.cpp
index c3e89b8..012f4e8 100644
--- a/src/PJSIPRegistrarModuleConstruction.cpp
+++ b/src/PJSIPRegistrarModuleConstruction.cpp
@@ -21,7 +21,7 @@ using namespace AsteriskSCF::SIP::Registration::V1;
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 static char registrarModuleName[] = "PJSIPRegistrarModule";
diff --git a/src/PJSIPSessionModule.cpp b/src/PJSIPSessionModule.cpp
index f8de853..b6a01d2 100644
--- a/src/PJSIPSessionModule.cpp
+++ b/src/PJSIPSessionModule.cpp
@@ -64,7 +64,7 @@ const std::string ConnectedCallbackName("connected");
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::Core::Routing::V1;
@@ -74,7 +74,7 @@ using namespace AsteriskSCF::SessionCommunications::ExtensionPoints::V1;
 using namespace AsteriskSCF::Media::V1;
 using namespace AsteriskSCF::Media::RTP::V1;
 using namespace AsteriskSCF::Media::SDP::V1;
-using namespace AsteriskSCF::Replication::SIPSessionManager::V1;
+using namespace AsteriskSCF::Replication::SIPSessionGateway::V1;
 using namespace AsteriskSCF::System::ThreadPool::V1;
 using namespace AsteriskSCF::System::WorkQueue::V1;
 using namespace AsteriskSCF::WorkQueue;
@@ -2456,5 +2456,5 @@ void SessionWork::enqueueWork(const SuspendableWorkPtr& work)
     }
 }
 
-}; //end namespace SIPSessionManager
+}; //end namespace SIPSessionGateway
 }; //end namespace AsteriskSCF
diff --git a/src/PJSIPSessionModule.h b/src/PJSIPSessionModule.h
index 941704b..91fb6e4 100644
--- a/src/PJSIPSessionModule.h
+++ b/src/PJSIPSessionModule.h
@@ -37,7 +37,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class PJSIPSessionModInfo
@@ -409,5 +409,5 @@ private:
 
 typedef IceUtil::Handle<SIPAMICallbackCookie> SIPAMICallbackCookiePtr;
 
-}; //end namespace SIPSessionManager
+}; //end namespace SIPSessionGateway
 }; //end namespace AsteriskSCF
diff --git a/src/PJSIPSessionModuleConstruction.cpp b/src/PJSIPSessionModuleConstruction.cpp
index fa38aab..f5fe146 100644
--- a/src/PJSIPSessionModuleConstruction.cpp
+++ b/src/PJSIPSessionModuleConstruction.cpp
@@ -33,7 +33,7 @@ const std::string SessionCreationExtensionPointId("SIPSessionCreationExtensionPo
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::WorkQueue;
@@ -178,21 +178,21 @@ PJSIPSessionModule::PJSIPSessionModule(pjsip_endpoint *endpt,
     if (pjsip_ua_instance()->id == -1)
     {
         pj_bzero(&mUaParam, sizeof(&mUaParam));
-        mUaParam.on_dlg_forked = AsteriskSCF::SIPSessionManager::uaOnDialogForked;
+        mUaParam.on_dlg_forked = AsteriskSCF::SIPSessionGateway::uaOnDialogForked;
     }
 
     if (pjsip_inv_usage_instance()->id == -1)
     {
         pj_bzero(&mInvCallback, sizeof(mInvCallback));
-        mInvCallback.on_state_changed = AsteriskSCF::SIPSessionManager::invOnStateChanged;
-        mInvCallback.on_new_session = AsteriskSCF::SIPSessionManager::invOnNewSession;
-        mInvCallback.on_tsx_state_changed = AsteriskSCF::SIPSessionManager::invOnTsxStateChanged;
-        mInvCallback.on_rx_offer = AsteriskSCF::SIPSessionManager::invOnRxOffer;
-        mInvCallback.on_create_offer = AsteriskSCF::SIPSessionManager::invOnCreateOffer;
-        mInvCallback.on_media_update = AsteriskSCF::SIPSessionManager::invOnMediaUpdate;
+        mInvCallback.on_state_changed = AsteriskSCF::SIPSessionGateway::invOnStateChanged;
+        mInvCallback.on_new_session = AsteriskSCF::SIPSessionGateway::invOnNewSession;
+        mInvCallback.on_tsx_state_changed = AsteriskSCF::SIPSessionGateway::invOnTsxStateChanged;
+        mInvCallback.on_rx_offer = AsteriskSCF::SIPSessionGateway::invOnRxOffer;
+        mInvCallback.on_create_offer = AsteriskSCF::SIPSessionGateway::invOnCreateOffer;
+        mInvCallback.on_media_update = AsteriskSCF::SIPSessionGateway::invOnMediaUpdate;
         //mInvCallback.on_send_ack = invOnSendAck;
-        mInvCallback.on_redirected = AsteriskSCF::SIPSessionManager::invOnRedirected;
-	mInvCallback.on_send_reinvite_response = AsteriskSCF::SIPSessionManager::invOnSendReinviteResponse;
+        mInvCallback.on_redirected = AsteriskSCF::SIPSessionGateway::invOnRedirected;
+	mInvCallback.on_send_reinvite_response = AsteriskSCF::SIPSessionGateway::invOnSendReinviteResponse;
     }
 
     pjsip_tsx_layer_init_module(endpt);
@@ -225,5 +225,5 @@ PJSIPSessionModule::~PJSIPSessionModule()
     }
 }
 
-}; //end namespace SIPSessionManager
+}; //end namespace SIPSessionGateway
 }; //end namespace AsteriskSCF
diff --git a/src/SIPClientRegistration.cpp b/src/SIPClientRegistration.cpp
index 10a86e7..bb5f4e1 100644
--- a/src/SIPClientRegistration.cpp
+++ b/src/SIPClientRegistration.cpp
@@ -24,11 +24,11 @@ using namespace AsteriskSCF::System::Logging;
 namespace
 {
 
-Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionManager");
+Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
-using namespace AsteriskSCF::SIPSessionManager;
+using namespace AsteriskSCF::SIPSessionGateway;
 using namespace AsteriskSCF::System::Hook::V1;
-using namespace AsteriskSCF::Configuration::SIPSessionManager::V1;
+using namespace AsteriskSCF::Configuration::SIPSessionGateway::V1;
 using namespace AsteriskSCF::System::Component::V1;
 using namespace AsteriskSCF::System::V1;
 
@@ -86,7 +86,7 @@ struct MakeContact
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class RescheduleRegister : public IceUtil::TimerTask
diff --git a/src/SIPClientRegistration.h b/src/SIPClientRegistration.h
index 90c5597..510d536 100644
--- a/src/SIPClientRegistration.h
+++ b/src/SIPClientRegistration.h
@@ -19,7 +19,7 @@
 #include <boost/thread.hpp>
 #include <pjsip_ua.h>
 
-#include <AsteriskSCF/Configuration/SIPSessionManager/SIPConfigurationIf.h>
+#include <AsteriskSCF/Configuration/SIPSessionGateway/SIPConfigurationIf.h>
 
 #include "SIPEndpoint.h"
 #include "AuthManager.h"
@@ -27,7 +27,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class RescheduleRegister;
@@ -63,7 +63,7 @@ public:
      * @param replica The replica interface on which to add listeners we create.
      */
     SIPRegistrationClient(
-            const AsteriskSCF::Configuration::SIPSessionManager::V1::SIPClientRegistrationItemPtr& confItem,
+            const AsteriskSCF::Configuration::SIPSessionGateway::V1::SIPClientRegistrationItemPtr& confItem,
             pjsip_endpoint* pjEndpoint,
             const SIPEndpointPtr& sipEndpoint,
             const AuthManagerPtr& manager,
@@ -85,7 +85,7 @@ public:
      * that a REGISTER will be sent out.
      */
     void createPJSIPRegistration(
-            const AsteriskSCF::Configuration::SIPSessionManager::V1::SIPClientRegistrationItemPtr& confItem,
+            const AsteriskSCF::Configuration::SIPSessionGateway::V1::SIPClientRegistrationItemPtr& confItem,
             pjsip_endpoint* pjEndpoint,
             const SIPEndpointPtr& sipEndpoint);
 
@@ -103,7 +103,7 @@ public:
     void destroyPJSIPRegistration();
 
     void updateRegistration(
-            const AsteriskSCF::Configuration::SIPSessionManager::V1::SIPClientRegistrationItemPtr& confItem,
+            const AsteriskSCF::Configuration::SIPSessionGateway::V1::SIPClientRegistrationItemPtr& confItem,
             pjsip_endpoint *pjEndpoint,
             const SIPEndpointPtr& sipEndpoint);
 
@@ -124,7 +124,7 @@ private:
      *
      * @param contacts The list of contacts to put in the outbound REGISTER.
      */
-    void setContacts(const AsteriskSCF::Configuration::SIPSessionManager::V1::ContactInfoSeq& contacts);
+    void setContacts(const AsteriskSCF::Configuration::SIPSessionGateway::V1::ContactInfoSeq& contacts);
 
 
     /**
@@ -165,7 +165,7 @@ private:
     /**
      * The contact headers to place in REGISTER messages.
      */
-    AsteriskSCF::Configuration::SIPSessionManager::V1::ContactInfoSeq mContacts;
+    AsteriskSCF::Configuration::SIPSessionGateway::V1::ContactInfoSeq mContacts;
     
     /**
      * The central point from which to get information such as authentication hooks.
diff --git a/src/SIPConfiguration.cpp b/src/SIPConfiguration.cpp
index 1017b03..1319394 100644
--- a/src/SIPConfiguration.cpp
+++ b/src/SIPConfiguration.cpp
@@ -43,7 +43,7 @@
 
 using namespace AsteriskSCF::System::Logging;
 using namespace AsteriskSCF::System::Configuration::V1;
-using namespace AsteriskSCF::Configuration::SIPSessionManager::V1;
+using namespace AsteriskSCF::Configuration::SIPSessionGateway::V1;
 using namespace AsteriskSCF::SessionCommunications::PartyIdentification::V1;
 using namespace AsteriskSCF::Core::Routing::V1;
 using namespace AsteriskSCF::System::V1;
@@ -62,7 +62,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 /**
@@ -2233,9 +2233,9 @@ void ConfigurationServiceImpl::removeConfigurationGroups(
 };
 };
 
-using namespace AsteriskSCF::SIPSessionManager;
+using namespace AsteriskSCF::SIPSessionGateway;
 
-AsteriskSCF::System::Configuration::V1::ConfigurationServicePtr  AsteriskSCF::SIPSessionManager::createConfigurationServant(
+AsteriskSCF::System::Configuration::V1::ConfigurationServicePtr  AsteriskSCF::SIPSessionGateway::createConfigurationServant(
     const PJSIPManagerPtr& manager,
     const boost::shared_ptr<SIPEndpointFactory>& endpointFactory,
     const std::string& id,
diff --git a/src/SIPConfiguration.h b/src/SIPConfiguration.h
index 6117706..9679f0b 100644
--- a/src/SIPConfiguration.h
+++ b/src/SIPConfiguration.h
@@ -32,7 +32,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 typedef ::AsteriskSCF::Discovery::SmartProxy<AsteriskSCF::Core::Routing::V1::LocatorRegistryPrx> LocatorRegistrySmartPrx;
@@ -43,6 +43,6 @@ AsteriskSCF::System::Configuration::V1::ConfigurationServicePtr createConfigurat
     const std::string& routingId,
     const LocatorRegistrySmartPrx& locatorRegistry);
 
-}; //End namespace SIPSessionManager
+}; //End namespace SIPSessionGateway
 
 }; //End namespace AsteriskSCF
diff --git a/src/SIPEndpoint.cpp b/src/SIPEndpoint.cpp
index a26d5a8..5cd7a73 100644
--- a/src/SIPEndpoint.cpp
+++ b/src/SIPEndpoint.cpp
@@ -40,9 +40,9 @@ using namespace AsteriskSCF::Media::V1;
 using namespace AsteriskSCF::Media::SDP::V1;
 using namespace AsteriskSCF::Core::Discovery::V1;
 using namespace AsteriskSCF::SessionCommunications::V1;
-using namespace AsteriskSCF::Replication::SIPSessionManager::V1;
+using namespace AsteriskSCF::Replication::SIPSessionGateway::V1;
 using namespace AsteriskSCF::Discovery;
-using namespace AsteriskSCF::Configuration::SIPSessionManager::V1;
+using namespace AsteriskSCF::Configuration::SIPSessionGateway::V1;
 using namespace AsteriskSCF::System::Component::V1;
 using namespace AsteriskSCF::Operations;
 
@@ -53,7 +53,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 string cookieKey(string &endpointName, const AsteriskSCF::SessionCommunications::V1::SessionCookiePtr& cookie)
@@ -347,11 +347,11 @@ void SIPEndpoint::setSecureTransport(enum Direction direction)
     mImplPriv->mConfig.transportConfig.secureTransport = direction;
 }
 
-void SIPEndpoint::setDTMFMethod(AsteriskSCF::Configuration::SIPSessionManager::V1::SIPDTMFOption dtmf)
+void SIPEndpoint::setDTMFMethod(AsteriskSCF::Configuration::SIPSessionGateway::V1::SIPDTMFOption dtmf)
 {
     mImplPriv->mConfig.sessionConfig.dtmf = dtmf;
     if (mImplPriv->mConfig.sessionConfig.dtmf ==
-            AsteriskSCF::Configuration::SIPSessionManager::V1::RFC4733)
+            AsteriskSCF::Configuration::SIPSessionGateway::V1::RFC4733)
     {
         //For RFC 4733, we need to include information in the SDP about
         //the format, so we need to add a new format to the endpoint's
@@ -613,7 +613,7 @@ AsteriskSCF::SessionCommunications::V1::SessionPrx SIPEndpoint::createSession(
 /**
  * This version of this overloaded method is called for sessions originating at this endpoint. 
  */
-AsteriskSCF::SIPSessionManager::SIPSessionPtr SIPEndpoint::createSession(const std::string& destination)
+AsteriskSCF::SIPSessionGateway::SIPSessionPtr SIPEndpoint::createSession(const std::string& destination)
 {
     vector<SessionListenerPrx> defaultListeners = mImplPriv->mDefaultListeners->getAll();
     AsteriskSCF::SessionCommunications::V1::SessionCookies defaultCookies = mImplPriv->mDefaultSessionCookies->getAll();
@@ -654,8 +654,8 @@ SIPSessionPtr SIPEndpoint::createSession
 		const Ice::Identity& controllerid,
                 const Ice::Identity& mediaid,
                 const OperationContextPtr& originalContext,
-                const AsteriskSCF::Replication::SIPSessionManager::V1::RTPMediaSessionDict& mediasessions,
-                const AsteriskSCF::Replication::SIPSessionManager::V1::UDPTLMediaSessionSeq& udptlMediaSessions,
+                const AsteriskSCF::Replication::SIPSessionGateway::V1::RTPMediaSessionDict& mediasessions,
+                const AsteriskSCF::Replication::SIPSessionGateway::V1::UDPTLMediaSessionSeq& udptlMediaSessions,
                 const AsteriskSCF::Media::V1::StreamSourceSeq& sources,
                 const AsteriskSCF::Media::V1::StreamSinkSeq& sinks)
 {
@@ -1100,5 +1100,5 @@ StreamInformationDict SIPEndpoint::getStreamTopology()
     return topology;
 }
 
-}; // end SIPSessionManager
+}; // end SIPSessionGateway
 }; // end AsteriskSCF
diff --git a/src/SIPEndpoint.h b/src/SIPEndpoint.h
index 8ebc217..b6369a5 100644
--- a/src/SIPEndpoint.h
+++ b/src/SIPEndpoint.h
@@ -33,7 +33,7 @@
 #include <AsteriskSCF/Media/MediaIf.h>
 #include <AsteriskSCF/Media/RTP/MediaRTPIf.h>
 #include <AsteriskSCF/Media/SDP/MediaSDPIf.h>
-#include <AsteriskSCF/Configuration/SIPSessionManager/SIPConfigurationIf.h>
+#include <AsteriskSCF/Configuration/SIPSessionGateway/SIPConfigurationIf.h>
 #include <AsteriskSCF/System/Component/ReplicaIf.h>
 
 #include "SIPSession.h"
@@ -43,7 +43,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 //
 // TODO: All of these config classes should be moved to a separate header file. This would
@@ -171,7 +171,7 @@ public:
     bool udptlWithTURN;
     // The method by which we will transmit
     // DTMF to an endpoint
-    AsteriskSCF::Configuration::SIPSessionManager::V1::SIPDTMFOption dtmf;
+    AsteriskSCF::Configuration::SIPSessionGateway::V1::SIPDTMFOption dtmf;
     // 
     // Enables ICE transport.
     //
@@ -356,15 +356,15 @@ public:
     // TODO: Find a way to use SIPSessionPtr here, right now trying to do so results in the world exploding due to
     // dependency insanity
     //
-    AsteriskSCF::SIPSessionManager::SIPSessionPtr createSession(const std::string&);
-    AsteriskSCF::SIPSessionManager::SIPSessionPtr createSession(
+    AsteriskSCF::SIPSessionGateway::SIPSessionPtr createSession(const std::string&);
+    AsteriskSCF::SIPSessionGateway::SIPSessionPtr createSession(
         const std::string&, 
         const Ice::Identity&, 
         const Ice::Identity&,                                  
         const Ice::Identity&, 
         const AsteriskSCF::System::V1::OperationContextPtr& originalContext,
-        const AsteriskSCF::Replication::SIPSessionManager::V1::RTPMediaSessionDict&,
-        const AsteriskSCF::Replication::SIPSessionManager::V1::UDPTLMediaSessionSeq&,
+        const AsteriskSCF::Replication::SIPSessionGateway::V1::RTPMediaSessionDict&,
+        const AsteriskSCF::Replication::SIPSessionGateway::V1::UDPTLMediaSessionSeq&,
         const AsteriskSCF::Media::V1::StreamSourceSeq&, 
         const AsteriskSCF::Media::V1::StreamSinkSeq&);
 
@@ -419,9 +419,9 @@ public:
     void setSignalingNATOptions(bool enable);
 
     AsteriskSCF::Media::V1::StreamInformationDict getStreamTopology();
-    void setDTMFMethod(AsteriskSCF::Configuration::SIPSessionManager::V1::SIPDTMFOption dtmf);
+    void setDTMFMethod(AsteriskSCF::Configuration::SIPSessionGateway::V1::SIPDTMFOption dtmf);
 
-    void updateClientRegistrations(AsteriskSCF::Configuration::SIPSessionManager::V1::SIPClientRegistrationItemSeq& items);
+    void updateClientRegistrations(AsteriskSCF::Configuration::SIPSessionGateway::V1::SIPClientRegistrationItemSeq& items);
 
     void addDefaultSessionCookie(
         const AsteriskSCF::SessionCommunications::V1::SessionCookiePtr& cookie);
@@ -448,6 +448,6 @@ typedef IceUtil::Handle<SIPEndpoint> SIPEndpointPtr;
 
 typedef std::vector<SIPEndpointPtr> SIPEndpointSeq;
 
-}; //End namespace SIPSessionManager
+}; //End namespace SIPSessionGateway
 
 }; //End namespace AsteriskSCF
diff --git a/src/SIPEndpointFactory.cpp b/src/SIPEndpointFactory.cpp
index 307586b..21b433e 100644
--- a/src/SIPEndpointFactory.cpp
+++ b/src/SIPEndpointFactory.cpp
@@ -29,7 +29,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 SIPEndpointFactory::SIPEndpointFactory(
@@ -100,5 +100,5 @@ void SIPEndpointFactory::setReplicaProxy(const ReplicaPrx& replica)
     mReplica = replica;
 }
 
-}; // end SIPSessionManager
+}; // end SIPSessionGateway
 }; // end AsteriskSCF
diff --git a/src/SIPEndpointFactory.h b/src/SIPEndpointFactory.h
index 5963f8d..810e98b 100644
--- a/src/SIPEndpointFactory.h
+++ b/src/SIPEndpointFactory.h
@@ -28,7 +28,7 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 /**
@@ -89,5 +89,5 @@ private:
     AuthManagerPtr mAuthManager;
 };
 
-}; // end SIPSessionManager
+}; // end SIPSessionGateway
 }; // end AsteriskSCF
diff --git a/src/SIPRegistrarListener.cpp b/src/SIPRegistrarListener.cpp
index 6fd2084..f01538b 100644
--- a/src/SIPRegistrarListener.cpp
+++ b/src/SIPRegistrarListener.cpp
@@ -29,7 +29,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::SIP::Registration::V1;
@@ -155,5 +155,5 @@ void SIPDefaultRegistrarListener::contactsRemoved(
     }
 }
 
-} // namespace SIPSessionManager
+} // namespace SIPSessionGateway
 } // namespace AsteriskSCF
diff --git a/src/SIPRegistrarListener.h b/src/SIPRegistrarListener.h
index 1e6e017..09ee54d 100644
--- a/src/SIPRegistrarListener.h
+++ b/src/SIPRegistrarListener.h
@@ -25,7 +25,7 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class SIPDefaultRegistrarListener : public AsteriskSCF::SIP::Registration::V1::RegistrarListener
@@ -46,5 +46,5 @@ private:
     pj_caching_pool mCachingPool;
 };
 
-} // namespace SIPSessionManager
+} // namespace SIPSessionGateway
 } // namespace AsteriskSCF
diff --git a/src/SIPReplicationContext.h b/src/SIPReplicationContext.h
index f2b5954..981f94e 100644
--- a/src/SIPReplicationContext.h
+++ b/src/SIPReplicationContext.h
@@ -25,9 +25,9 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
-typedef AsteriskSCF::Discovery::SmartProxy<AsteriskSCF::Replication::SIPSessionManager::V1::SIPStateReplicatorPrx> ReplicatorSmartPrx;
+typedef AsteriskSCF::Discovery::SmartProxy<AsteriskSCF::Replication::SIPSessionGateway::V1::SIPStateReplicatorPrx> ReplicatorSmartPrx;
 
 /** 
  * This class provides the component's classes with the context needed to perform replication. 
@@ -79,5 +79,5 @@ private:
 };
 typedef boost::shared_ptr<SIPReplicationContext> SIPReplicationContextPtr;
 
-} // end SIPSessionManager
+} // end SIPSessionGateway
 } // end AsteriskSCF
diff --git a/src/SIPSession.cpp b/src/SIPSession.cpp
index 9c4b21b..aabfde6 100755
--- a/src/SIPSession.cpp
+++ b/src/SIPSession.cpp
@@ -44,7 +44,7 @@
 #include <AsteriskSCF/Media/UDPTL/MediaUDPTLIf.h>
 #include <AsteriskSCF/Media/Formats/T38UDPTLFormatIf.h>
 #include <AsteriskSCF/Media/NetworkIf.h>
-#include <AsteriskSCF/SessionCookies/SIPSessionManager/SIPSessionCookiesIf.h>
+#include <AsteriskSCF/SessionCookies/SIPSessionGateway/SIPSessionCookiesIf.h>
 #include <AsteriskSCF/Collections/HandleSet.h>
 #include <AsteriskSCF/Operations/OperationContextCache.h>
 #include <AsteriskSCF/Operations/OperationContext.h>
@@ -77,7 +77,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::System::WorkQueue::V1;
@@ -1434,7 +1434,7 @@ void SIPSession::activateIceObjects(const AsteriskSCF::SessionCommunications::Ex
 
 void SIPSession::setTelephonyEventSourcesAndSinks(const SIPEndpointConfig& config)
 {
-    if (config.sessionConfig.dtmf == AsteriskSCF::Configuration::SIPSessionManager::V1::INFO)
+    if (config.sessionConfig.dtmf == AsteriskSCF::Configuration::SIPSessionGateway::V1::INFO)
     {
         mImplPriv->mEventSink = new SIPTelephonyEventSink(mImplPriv->mSessionWork, mImplPriv->mInviteSession);
         mImplPriv->mEventSinkPrx =
@@ -1503,8 +1503,8 @@ SIPSessionPtr SIPSession::create(
     const Ice::Identity& sessionid,
     const Ice::Identity& controllerid,
     const Ice::Identity& mediaid, 
-    const AsteriskSCF::Replication::SIPSessionManager::V1::RTPMediaSessionDict& mediasessions,
-    const AsteriskSCF::Replication::SIPSessionManager::V1::UDPTLMediaSessionSeq& udptlMediaSessions,
+    const AsteriskSCF::Replication::SIPSessionGateway::V1::RTPMediaSessionDict& mediasessions,
+    const AsteriskSCF::Replication::SIPSessionGateway::V1::UDPTLMediaSessionSeq& udptlMediaSessions,
     const AsteriskSCF::Media::V1::StreamSourceSeq& sources, 
     const AsteriskSCF::Media::V1::StreamSinkSeq& sinks,
     const PJSIPManagerPtr& manager, 
@@ -1605,8 +1605,8 @@ SIPSession::SIPSession(
     const Ice::Identity& sessionid,
     const Ice::Identity& controllerid,
     const Ice::Identity& mediaid,
-    const AsteriskSCF::Replication::SIPSessionManager::V1::RTPMediaSessionDict& mediasessions,
-    const AsteriskSCF::Replication::SIPSessionManager::V1::UDPTLMediaSessionSeq& udptlMediaSessions,
+    const AsteriskSCF::Replication::SIPSessionGateway::V1::RTPMediaSessionDict& mediasessions,
+    const AsteriskSCF::Replication::SIPSessionGateway::V1::UDPTLMediaSessionSeq& udptlMediaSessions,
     const AsteriskSCF::Media::V1::StreamSourceSeq& sources,
     const AsteriskSCF::Media::V1::StreamSinkSeq& sinks,
     const PJSIPManagerPtr& manager,
@@ -2474,7 +2474,7 @@ private:
     void addReferredBy(pjsip_tx_data *packet)
     {
         AsteriskSCF::SessionCommunications::V1::SessionCookieDict::const_iterator iter =
-            mImplPriv->mSessionCookies.find(AsteriskSCF::SessionCookies::SIPSessionManager::V1::ReferredByCookie::ice_staticId());
+            mImplPriv->mSessionCookies.find(AsteriskSCF::SessionCookies::SIPSessionGateway::V1::ReferredByCookie::ice_staticId());
 
         if (iter == mImplPriv->mSessionCookies.end())
         {
@@ -2482,8 +2482,8 @@ private:
             return;
         }
 
-        AsteriskSCF::SessionCookies::SIPSessionManager::V1::ReferredByCookiePtr referredBy = 
-            AsteriskSCF::SessionCookies::SIPSessionManager::V1::ReferredByCookiePtr::dynamicCast(iter->second);
+        AsteriskSCF::SessionCookies::SIPSessionGateway::V1::ReferredByCookiePtr referredBy = 
+            AsteriskSCF::SessionCookies::SIPSessionGateway::V1::ReferredByCookiePtr::dynamicCast(iter->second);
 
         if (referredBy->value.empty())
         {
@@ -3558,7 +3558,7 @@ pjmedia_sdp_session *SIPSession::createSDPOffer(
             RTPOptionsPtr options(new RTPOptions());
             RTPAllocationOutputsPtr outputs;
 
-            if (config.sessionConfig.dtmf == AsteriskSCF::Configuration::SIPSessionManager::V1::RFC4733)
+            if (config.sessionConfig.dtmf == AsteriskSCF::Configuration::SIPSessionGateway::V1::RFC4733)
             {
                 options->handleTelephonyEvents = true;
             }
@@ -4074,7 +4074,7 @@ pjmedia_sdp_session *SIPSession::createSDPAnswer(
                 RTPAllocationOutputsPtr outputs;
 
                 SIPEndpointConfig config = mImplPriv->mEndpoint->getConfig();
-                if (config.sessionConfig.dtmf == AsteriskSCF::Configuration::SIPSessionManager::V1::RFC4733)
+                if (config.sessionConfig.dtmf == AsteriskSCF::Configuration::SIPSessionGateway::V1::RFC4733)
                 {
                     options->handleTelephonyEvents = true;
                 }
@@ -4923,5 +4923,5 @@ bool SIPSession::isTelephonyEventSink()
     return mImplPriv->mEventSink != 0;
 }
 
-}; // end SIPSessionManager
+}; // end SIPSessionGateway
 }; // end AsteriskSCF
diff --git a/src/SIPSession.h b/src/SIPSession.h
index 2408259..867e842 100644
--- a/src/SIPSession.h
+++ b/src/SIPSession.h
@@ -42,7 +42,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 //
@@ -146,8 +146,8 @@ public:
         const Ice::Identity& sessionid,
         const Ice::Identity& controllerid,
         const Ice::Identity& mediaid, 
-	const AsteriskSCF::Replication::SIPSessionManager::V1::RTPMediaSessionDict& mediasessions,
-        const AsteriskSCF::Replication::SIPSessionManager::V1::UDPTLMediaSessionSeq& udptlMediaSessions,
+	const AsteriskSCF::Replication::SIPSessionGateway::V1::RTPMediaSessionDict& mediasessions,
+        const AsteriskSCF::Replication::SIPSessionGateway::V1::UDPTLMediaSessionSeq& udptlMediaSessions,
         const AsteriskSCF::Media::V1::StreamSourceSeq& sources, 
 	const AsteriskSCF::Media::V1::StreamSinkSeq& sinks,
         const PJSIPManagerPtr& manager, 
@@ -378,9 +378,9 @@ public:
 
     void setStreams(const AsteriskSCF::Media::V1::StreamInformationDict& streams);
 
-    AsteriskSCF::Replication::SIPSessionManager::V1::RTPMediaSessionDict getRTPMediaSessions();
+    AsteriskSCF::Replication::SIPSessionGateway::V1::RTPMediaSessionDict getRTPMediaSessions();
 
-    AsteriskSCF::Replication::SIPSessionManager::V1::UDPTLMediaSessionSeq getUDPTLMediaSessions();
+    AsteriskSCF::Replication::SIPSessionGateway::V1::UDPTLMediaSessionSeq getUDPTLMediaSessions();
 
     void enqueueSessionWork(const AsteriskSCF::System::WorkQueue::V1::SuspendableWorkPtr&);
 
@@ -417,8 +417,8 @@ private:
     SIPSession(
         const AsteriskSCF::System::V1::OperationContextPtr&,
         const Ice::ObjectAdapterPtr&, const SIPEndpointPtr&, const std::string&, const Ice::Identity&, const Ice::Identity&,
-        const Ice::Identity&, const AsteriskSCF::Replication::SIPSessionManager::V1::RTPMediaSessionDict&,
-        const AsteriskSCF::Replication::SIPSessionManager::V1::UDPTLMediaSessionSeq&,
+        const Ice::Identity&, const AsteriskSCF::Replication::SIPSessionGateway::V1::RTPMediaSessionDict&,
+        const AsteriskSCF::Replication::SIPSessionGateway::V1::UDPTLMediaSessionSeq&,
         const AsteriskSCF::Media::V1::StreamSourceSeq&, const AsteriskSCF::Media::V1::StreamSinkSeq&,
         const PJSIPManagerPtr& manager, const AsteriskSCF::Core::Discovery::V1::ServiceLocatorPrx& serviceLocator,
         const SIPReplicationContextPtr& replicationContext,
@@ -438,6 +438,6 @@ private:
     boost::shared_ptr<SIPSessionPriv> mImplPriv;
 };
 
-}; //End namespace SIPSessionManager
+}; //End namespace SIPSessionGateway
 
 }; //End namespace AsteriskSCF
diff --git a/src/SIPSessionManagerEndpointLocator.cpp b/src/SIPSessionGatewayEndpointLocator.cpp
similarity index 92%
rename from src/SIPSessionManagerEndpointLocator.cpp
rename to src/SIPSessionGatewayEndpointLocator.cpp
index 4bfa87b..496eaa1 100644
--- a/src/SIPSessionManagerEndpointLocator.cpp
+++ b/src/SIPSessionGatewayEndpointLocator.cpp
@@ -16,7 +16,7 @@
 #include <AsteriskSCF/Logger.h>
 
 #include "SIPEndpointFactory.h"
-#include "SIPSessionManagerEndpointLocator.h"
+#include "SIPSessionGatewayEndpointLocator.h"
 #include "SIPEndpoint.h"
 
 #include <boost/thread.hpp>
@@ -24,7 +24,7 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::System::Logging;
@@ -40,7 +40,7 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
  * Note: This interface is shared by the Routing Service, which is why it's specified as AMD. However, we aren't currently
  * using any asynchrounous features in forming our reply. 
  */
-void SIPSessionManagerEndpointLocator::lookup_async(const ::AsteriskSCF::Core::Routing::V1::AMD_EndpointLocator_lookupPtr& cb, const ::std::string& destination, const ::Ice::Current&)
+void SIPSessionGatewayEndpointLocator::lookup_async(const ::AsteriskSCF::Core::Routing::V1::AMD_EndpointLocator_lookupPtr& cb, const ::std::string& destination, const ::Ice::Current&)
 {
     AsteriskSCF::Core::Endpoint::V1::EndpointSeq endpoints;
     SIPEndpointPtr endpoint = mEndpointFactory->findByName(destination);
@@ -61,6 +61,6 @@ void SIPSessionManagerEndpointLocator::lookup_async(const ::AsteriskSCF::Core::R
     cb->ice_exception(::AsteriskSCF::Core::Routing::V1::DestinationNotFoundException(destination));
 }
 
-}; // end SIPSessionManager
+}; // end SIPSessionGateway
 }; // end AsteriskSCF
 
diff --git a/src/SIPSessionManagerEndpointLocator.h b/src/SIPSessionGatewayEndpointLocator.h
similarity index 89%
rename from src/SIPSessionManagerEndpointLocator.h
rename to src/SIPSessionGatewayEndpointLocator.h
index b5f3e1a..1f6737c 100644
--- a/src/SIPSessionManagerEndpointLocator.h
+++ b/src/SIPSessionGatewayEndpointLocator.h
@@ -22,7 +22,7 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 /**
@@ -31,10 +31,10 @@ namespace SIPSessionManager
  * Session Manager component, so that the rest of the Asterisk SCF system
  * can bridge our endpoints.
  */
-class SIPSessionManagerEndpointLocator : public AsteriskSCF::Core::Routing::V1::EndpointLocator
+class SIPSessionGatewayEndpointLocator : public AsteriskSCF::Core::Routing::V1::EndpointLocator
 {
 public:
-    SIPSessionManagerEndpointLocator(const boost::shared_ptr<SIPEndpointFactory>& factory) :
+    SIPSessionGatewayEndpointLocator(const boost::shared_ptr<SIPEndpointFactory>& factory) :
         mEndpointFactory(factory) { };
 
 public:  // Overrides of EndpointLocator
@@ -52,5 +52,5 @@ private:
     boost::shared_ptr<SIPEndpointFactory> mEndpointFactory;
 };
 
-}; // end SIPSessionManager
+}; // end SIPSessionGateway
 }; // end AsteriskSCF
diff --git a/src/SIPSessionManagerEventPublisher.h b/src/SIPSessionGatewayEventPublisher.h
similarity index 81%
rename from src/SIPSessionManagerEventPublisher.h
rename to src/SIPSessionGatewayEventPublisher.h
index a069dd5..ab99690 100644
--- a/src/SIPSessionManagerEventPublisher.h
+++ b/src/SIPSessionGatewayEventPublisher.h
@@ -22,17 +22,17 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
-class SIPSessionManagerEventPublisherPriv;
+class SIPSessionGatewayEventPublisherPriv;
 
 /**
  * Publishes key events to the rest of the system.
  */
-class SIPSessionManagerEventPublisher
+class SIPSessionGatewayEventPublisher
 {
 public:
-    SIPSessionManagerEventPublisher(const Ice::ObjectAdapterPtr& adapter);
+    SIPSessionGatewayEventPublisher(const Ice::ObjectAdapterPtr& adapter);
 
     /**
      * Send a message to the service's event topic to report a lookup event.
@@ -44,9 +44,9 @@ public:
 
 
 private:
-    boost::shared_ptr<SIPSessionManagerEventPublisherPriv> mImpl; // pimpl idiom applied.
+    boost::shared_ptr<SIPSessionGatewayEventPublisherPriv> mImpl; // pimpl idiom applied.
 };
 
-}; // end SIPSessionManager
+}; // end SIPSessionGateway
 }; // end AsteriskSCF
 
diff --git a/src/SIPStateReplicator.h b/src/SIPStateReplicator.h
index b86a5bb..3fd80b6 100644
--- a/src/SIPStateReplicator.h
+++ b/src/SIPStateReplicator.h
@@ -19,7 +19,7 @@
 #include "SIPEndpointFactory.h"
 #include <Ice/Ice.h>
 #include <AsteriskSCF/Replication/StateReplicator.h>
-#include <AsteriskSCF/Replication/SIPSessionManager/SIPStateReplicationIf.h>
+#include <AsteriskSCF/Replication/SIPSessionGateway/SIPStateReplicationIf.h>
 #include <AsteriskSCF/Discovery/SmartProxy.h>
 #include <SIPStateReplicationIf.h>
 
@@ -27,13 +27,13 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 typedef AsteriskSCF::Replication::StateReplicator<
-    AsteriskSCF::Replication::SIPSessionManager::V1::SIPStateReplicator, 
-    AsteriskSCF::Replication::SIPSessionManager::V1::SIPStateItemPtr, std::string,
-    AsteriskSCF::Replication::SIPSessionManager::V1::SIPStateReplicatorListenerPrx> SIPStateReplicatorI;
+    AsteriskSCF::Replication::SIPSessionGateway::V1::SIPStateReplicator, 
+    AsteriskSCF::Replication::SIPSessionGateway::V1::SIPStateItemPtr, std::string,
+    AsteriskSCF::Replication::SIPSessionGateway::V1::SIPStateReplicatorListenerPrx> SIPStateReplicatorI;
 typedef IceUtil::Handle<SIPStateReplicatorI> SIPStateReplicatorIPtr;
 
 //
@@ -41,7 +41,7 @@ typedef IceUtil::Handle<SIPStateReplicatorI> SIPStateReplicatorIPtr;
 //
 struct SIPStateReplicatorListenerImpl; 
 
-class SIPStateReplicatorListenerI : public AsteriskSCF::Replication::SIPSessionManager::V1::SIPStateReplicatorListener
+class SIPStateReplicatorListenerI : public AsteriskSCF::Replication::SIPSessionGateway::V1::SIPStateReplicatorListener
 {
 public:
     SIPStateReplicatorListenerI(
@@ -54,10 +54,10 @@ public:
         const Ice::StringSeq&, const Ice::Current&);
     void stateRemovedForItems(
         const AsteriskSCF::System::V1::OperationContextPtr&,
-        const AsteriskSCF::Replication::SIPSessionManager::V1::SIPStateItemSeq&, const Ice::Current&);
+        const AsteriskSCF::Replication::SIPSessionGateway::V1::SIPStateItemSeq&, const Ice::Current&);
     void stateSet(
         const AsteriskSCF::System::V1::OperationContextPtr&,
-        const AsteriskSCF::Replication::SIPSessionManager::V1::SIPStateItemSeq&, const Ice::Current&);
+        const AsteriskSCF::Replication::SIPSessionGateway::V1::SIPStateItemSeq&, const Ice::Current&);
     bool operator==(const SIPStateReplicatorListenerI &rhs);
 private:
     boost::shared_ptr<SIPStateReplicatorListenerImpl> mImpl;
diff --git a/src/SIPStateReplicatorListener.cpp b/src/SIPStateReplicatorListener.cpp
index 519587e..3c48ac2 100644
--- a/src/SIPStateReplicatorListener.cpp
+++ b/src/SIPStateReplicatorListener.cpp
@@ -31,11 +31,11 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::SIP::Registration::V1;
-using namespace AsteriskSCF::Replication::SIPSessionManager::V1;
+using namespace AsteriskSCF::Replication::SIPSessionGateway::V1;
 using namespace AsteriskSCF::System::V1;
 
 class SIPStateReplicatorItem
diff --git a/src/SIPTelephonyEventSink.cpp b/src/SIPTelephonyEventSink.cpp
index 4292ef8..6dabd74 100644
--- a/src/SIPTelephonyEventSink.cpp
+++ b/src/SIPTelephonyEventSink.cpp
@@ -20,7 +20,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::System::WorkQueue::V1;
diff --git a/src/SIPTelephonyEventSink.h b/src/SIPTelephonyEventSink.h
index 9502648..86e186b 100644
--- a/src/SIPTelephonyEventSink.h
+++ b/src/SIPTelephonyEventSink.h
@@ -22,7 +22,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class SIPTelephonyEventSink : public AsteriskSCF::SessionCommunications::V1::TelephonyEventSink, public AsteriskSCF::WorkQueue::Dispatched
diff --git a/src/SIPTelephonyEventSource.cpp b/src/SIPTelephonyEventSource.cpp
index de4cdd9..bd8f5db 100644
--- a/src/SIPTelephonyEventSource.cpp
+++ b/src/SIPTelephonyEventSource.cpp
@@ -25,7 +25,7 @@ using namespace AsteriskSCF::Operations;
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::System::WorkQueue::V1;
diff --git a/src/SIPTelephonyEventSource.h b/src/SIPTelephonyEventSource.h
index 9593130..e19e4b6 100644
--- a/src/SIPTelephonyEventSource.h
+++ b/src/SIPTelephonyEventSource.h
@@ -23,7 +23,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class SIPTelephonyEventSource : public AsteriskSCF::SessionCommunications::V1::TelephonyEventSource, public AsteriskSCF::WorkQueue::Dispatched
diff --git a/src/SIPTransfer.cpp b/src/SIPTransfer.cpp
index be8819f..8b334bb 100644
--- a/src/SIPTransfer.cpp
+++ b/src/SIPTransfer.cpp
@@ -22,7 +22,7 @@
 
 #include <AsteriskSCF/Operations/OperationContext.h>
 #include <AsteriskSCF/Logger.h>
-#include <AsteriskSCF/SessionCookies/SIPSessionManager/SIPSessionCookiesIf.h>
+#include <AsteriskSCF/SessionCookies/SIPSessionGateway/SIPSessionCookiesIf.h>
 #include <AsteriskSCF/Operations/OperationMonitor.h>
 
 using namespace AsteriskSCF::System::Logging;
@@ -38,7 +38,7 @@ pjsip_tx_data* createNotify(pjsip_dialog *dlg, pj_int32_t cseq, bool active)
 {
     pjsip_tx_data *tdata;
     
-    if (AsteriskSCF::SIPSessionManager::fail(pjsip_dlg_create_request(dlg, pjsip_get_notify_method(), -1, &tdata)))
+    if (AsteriskSCF::SIPSessionGateway::fail(pjsip_dlg_create_request(dlg, pjsip_get_notify_method(), -1, &tdata)))
     {
         lg(Warning) << "Unable to create NOTIFY request";
         return 0;
@@ -84,15 +84,15 @@ void addNotifyBody(pjsip_tx_data *tdata, const char *bodyText)
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 using namespace AsteriskSCF::SessionCommunications::V1;
 using namespace AsteriskSCF::SessionCommunications::ExtensionPoints::V1;
 using namespace AsteriskSCF::System::WorkQueue::V1;
 using namespace AsteriskSCF::System::Hook::V1;
-using namespace AsteriskSCF::SessionCookies::SIPSessionManager::V1;
-using namespace AsteriskSCF::Replication::SIPSessionManager::V1;
+using namespace AsteriskSCF::SessionCookies::SIPSessionGateway::V1;
+using namespace AsteriskSCF::Replication::SIPSessionGateway::V1;
 
 TransferListener::TransferListener(
         const Ice::ObjectAdapterPtr& adapter,
@@ -769,5 +769,5 @@ pjsip_dialog* HandleReferOperation::findDialogFromReplaces()
     return pjsip_ua_find_dialog(&replaces_tag_str, &to_tag_str, &from_tag_str, PJ_TRUE);
 }
 
-}; //end namespace SIPSessionManager
+}; //end namespace SIPSessionGateway
 }; //end namespace AsteriskSCF
diff --git a/src/SIPTransfer.h b/src/SIPTransfer.h
index 1b24e47..ed0f19d 100644
--- a/src/SIPTransfer.h
+++ b/src/SIPTransfer.h
@@ -17,7 +17,7 @@
 #include <AsteriskSCF/SessionCommunications/SessionCommunicationsIf.h>
 #include <AsteriskSCF/SessionCommunications/SessionCommunicationsExtensionPointsIf.h>
 #include <AsteriskSCF/Discovery/SmartProxy.h>
-#include <AsteriskSCF/Replication/SIPSessionManager/SIPStateReplicationIf.h>
+#include <AsteriskSCF/Replication/SIPSessionGateway/SIPStateReplicationIf.h>
 #include <AsteriskSCF/System/Hook/HookIf.h>
 #include <AsteriskSCF/Helpers/Retry.h>
 #include <AsteriskSCF/System/OperationsIf.h>
@@ -28,7 +28,7 @@
 namespace AsteriskSCF
 {
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class TransferListener : public AsteriskSCF::SessionCommunications::V1::SessionListener
@@ -123,7 +123,7 @@ private:
     /**
      * The item sent to the state replicator either to add or remove state
      */
-    AsteriskSCF::Replication::SIPSessionManager::V1::TransferSessionListenerStateItemPtr mStateItem;
+    AsteriskSCF::Replication::SIPSessionGateway::V1::TransferSessionListenerStateItemPtr mStateItem;
 
     AsteriskSCF::Operations::OperationContextCachePtr mOperationContextCache;
 };
@@ -241,7 +241,7 @@ private:
      * The state item used for adding and removing state
      * from the state replicator
      */
-    AsteriskSCF::Replication::SIPSessionManager::V1::TransferSessionCreationHookStateItemPtr mStateItem;
+    AsteriskSCF::Replication::SIPSessionGateway::V1::TransferSessionCreationHookStateItemPtr mStateItem;
 
     AsteriskSCF::Operations::OperationContextCachePtr mOperationContextCache;
 };
@@ -396,5 +396,5 @@ private:
     RetryPolicy mRetryPolicy;
 };
 
-}; //end namespace SIPSessionManager
+}; //end namespace SIPSessionGateway
 }; //end namespace AsteriskSCF
diff --git a/src/STUNModule.cpp b/src/STUNModule.cpp
index bdb917b..68449ed 100644
--- a/src/STUNModule.cpp
+++ b/src/STUNModule.cpp
@@ -28,12 +28,12 @@
 #include "PJUtil.h"
 
 using namespace AsteriskSCF::System::V1;
-using namespace AsteriskSCF::SIPSessionManager;
+using namespace AsteriskSCF::SIPSessionGateway;
 using namespace AsteriskSCF::System::Logging;
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 const pj_time_val DEFAULT_PROCESSING_TIMEOUT = { 0 /* seconds */, 100 /* milliseconds */ };
diff --git a/src/STUNTransport.cpp b/src/STUNTransport.cpp
index 2fbbbbe..bc9dd35 100644
--- a/src/STUNTransport.cpp
+++ b/src/STUNTransport.cpp
@@ -42,7 +42,7 @@ Logger logger = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 class STUNTransport;
diff --git a/src/STUNTransportConfig.cpp b/src/STUNTransportConfig.cpp
index e4e42aa..2e7e7ca 100644
--- a/src/STUNTransportConfig.cpp
+++ b/src/STUNTransportConfig.cpp
@@ -18,8 +18,8 @@
 #include "STUNTransport.h"
 #include "PJSIPManager.h"
 
-using namespace AsteriskSCF::SIPSessionManager;
-using namespace AsteriskSCF::Configuration::SIPSessionManager::V1;
... 187 lines suppressed ...


diff --git a/src/NATOptions.h b/src/NATOptions.h
index 58f6e6a..a00ba4a 100644
--- a/src/NATOptions.h
+++ b/src/NATOptions.h
@@ -20,7 +20,7 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 struct NATEndpointOptions 
 {
@@ -35,5 +35,5 @@ struct NATEndpointOptions
     {
     }
 };
-} /* End of namespace SIPSessionManager */
+} /* End of namespace SIPSessionGateway */
 } /* End of namespace AsteriskSCF */
diff --git a/src/PJUtil.h b/src/PJUtil.h
index d55379e..383d3de 100644
--- a/src/PJUtil.h
+++ b/src/PJUtil.h
@@ -20,7 +20,7 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 inline bool success(pj_status_t r)
@@ -33,5 +33,5 @@ inline bool fail(pj_status_t r)
     return !success(r);
 }
 
-} /* End of namespace SIPSessionManager */
+} /* End of namespace SIPSessionGateway */
 } /* End of namespace AsteriskSCF */
diff --git a/src/SIPModule.h b/src/SIPModule.h
index 6b3c3d5..3989227 100644
--- a/src/SIPModule.h
+++ b/src/SIPModule.h
@@ -22,7 +22,7 @@
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 /**
@@ -64,5 +64,5 @@ inline void onHandleEvents(const SIPModuleMap& modules)
     }
 }
 
-} /* End of namespace SIPSessionManager */
+} /* End of namespace SIPSessionGateway */
 } /* End of namespace AsteriskSCF */
diff --git a/src/SIPSessionManagerEventPublisher.cpp b/src/SIPSessionGatewayEventPublisher.cpp
similarity index 80%
rename from src/SIPSessionManagerEventPublisher.cpp
rename to src/SIPSessionGatewayEventPublisher.cpp
index 2a63ca4..43e1bd2 100644
--- a/src/SIPSessionManagerEventPublisher.cpp
+++ b/src/SIPSessionGatewayEventPublisher.cpp
@@ -14,7 +14,7 @@
  * at the top of the source tree.
  */
 
-#include "SIPSessionManagerEventPublisher.h"
+#include "SIPSessionGatewayEventPublisher.h"
 
 #include <Ice/Ice.h>
 #include <IceStorm/IceStorm.h>
@@ -32,16 +32,16 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 /**
  * The private implementation of SIPSessionManagerEventPublisher.
  */
-class SIPSessionManagerEventPublisherPriv
+class SIPSessionGatewayEventPublisherPriv
 {
 public:
-    SIPSessionManagerEventPublisherPriv(const Ice::ObjectAdapterPtr& adapter) :  mAdapter(adapter), mInitialized(false)
+    SIPSessionGatewayEventPublisherPriv(const Ice::ObjectAdapterPtr& adapter) :  mAdapter(adapter), mInitialized(false)
     {
         initialize();
     }
@@ -64,7 +64,7 @@ public:
                 return;
             }
 
-            lg(Debug) << "SIPSessionManagerEventPublisher::initialize(): Got IceStorm proxy: TopicManager.Proxy";
+            lg(Debug) << "SIPSessionGatewayEventPublisher::initialize(): Got IceStorm proxy: TopicManager.Proxy";
         }
         catch(const IceUtil::Exception&)
         {
@@ -91,7 +91,7 @@ public:
         }
 
         Ice::ObjectPrx publisher = topic->getPublisher();
-        mEventTopic = Event::SIPSessionManagerEventsPrx::uncheckedCast(publisher);
+        mEventTopic = Event::SIPSessionGatewayEventsPrx::uncheckedCast(publisher);
 
         mInitialized = true;
     }
@@ -103,7 +103,7 @@ public:
     {
         if (!mInitialized)
         {
-            lg(Error) << "Warning: Attempting to use SIPSessionManagerEventPublisher in uninitialized state! "
+            lg(Error) << "Warning: Attempting to use SIPSessionGatewayEventPublisher in uninitialized state! "
                 "IceStorm may be inaccessible.";
         }
 
@@ -111,7 +111,7 @@ public:
     }
 
 public:
-    Event::SIPSessionManagerEventsPrx mEventTopic;
+    Event::SIPSessionGatewayEventsPrx mEventTopic;
     Ice::ObjectAdapterPtr mAdapter;
     bool mInitialized;
 };
@@ -119,15 +119,15 @@ public:
 /**
  * Class constructor.
  */
-SIPSessionManagerEventPublisher::SIPSessionManagerEventPublisher(const Ice::ObjectAdapterPtr& adapter)
-    : mImpl(new SIPSessionManagerEventPublisherPriv(adapter))
+SIPSessionGatewayEventPublisher::SIPSessionGatewayEventPublisher(const Ice::ObjectAdapterPtr& adapter)
+    : mImpl(new SIPSessionGatewayEventPublisherPriv(adapter))
 {
 }
 
 /**
  * Send a message to the service's event topic to report a lookup event.
  */
-void SIPSessionManagerEventPublisher::sendLookupEvent(const ::std::string& destination,
+void SIPSessionGatewayEventPublisher::sendLookupEvent(const ::std::string& destination,
     ::AsteriskSCF::SIP::V1::Event::OperationResult result) const
 {
     if (!mImpl->isInitialized())
@@ -138,6 +138,6 @@ void SIPSessionManagerEventPublisher::sendLookupEvent(const ::std::string& desti
     mImpl->mEventTopic->lookupEvent(destination, result);
 }
 
-}; // end SIPSessionManager
+}; // end SIPSessionGateway
 }; // end AsteriskSCF
 
@@ -32,16 +32,16 @@ Logger lg = getLoggerFactory().getLogger("AsteriskSCF.SIPSessionGateway");
 
 /**
- * The private implementation of SIPSessionManagerEventPublisher.
+ * The private implementation of SIPSessionGatewayEventPublisher.
  */
diff --git a/src/STUNModule.h b/src/STUNModule.h
index 993ae53..b8a705c 100644
--- a/src/STUNModule.h
+++ b/src/STUNModule.h
@@ -39,7 +39,7 @@ class Logger;
 }
 }
 
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 // 
@@ -97,5 +97,5 @@ private:
 typedef boost::shared_ptr<STUNModule> STUNModulePtr;
 
 
-} /* End of namespace SIPSessionManager */
+} /* End of namespace SIPSessionGateway */
 } /* End of namespace AsteriskSCF */
diff --git a/src/STUNTransport.h b/src/STUNTransport.h
index bd4c378..4c43065 100644
--- a/src/STUNTransport.h
+++ b/src/STUNTransport.h
@@ -28,7 +28,7 @@ struct pjsip_endpoint;
 
 namespace AsteriskSCF
 {
-namespace SIPSessionManager
+namespace SIPSessionGateway
 {
 
 //
@@ -40,5 +40,5 @@ typedef boost::shared_ptr<PJSIPManager> PJSIPManagerPtr;
 TransportPtr createSTUNTransport(const PJSIPManagerPtr& sipManager, const AsteriskSCF::Helpers::AddressPtr& stunServer,
     const AsteriskSCF::Helpers::AddressPtr& host);
 
-} /* End of namespace SIPSessionManager */
+} /* End of namespace SIPSessionGateway */
 } /* End of namespace AsteriskSCF */
-- 
asterisk-scf/release/sip.git



More information about the asterisk-scf-commits mailing list